# sozlukpy

A basic Turkish dictionary
## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install foobar.

```bash
pip install sozlukpy
```

## License

[MIT](https://choosealicense.com/licenses/mit/)